export default async function initCloudrain() {
    let timeid = window.setInterval(loadJobStatus, 15000);
    $(document).ready(loadJobStatus);
    function loadJobStatus() {
        $(".job-status").each((index, job) => {
            const jobID = job.dataset.jobid;
            const repoPath = job.dataset.repopath;
            // const computeResource = job.dataset.resource
            const versionname = job.dataset.version
            const status_text = $(`#${jobID}-text`).text()
            const finalState = ['STOPPED','CREATE_FAILED','UNAVAILABLE','DELETED','RESIZE_FAILED','SUCCEEDED','IMAGE_FAILED','SUBMIT_FAILED','DELETE_FAILED','KILLED','COMPLETED','FAILED','CANCELED','LOST','START_FAILED','SUBMIT_MODEL_FAILED','DEPLOY_SERVICE_FAILED','CHECK_FAILED']
            if (finalState.includes(status_text)) {
                return
            }
            // const diffResource = computeResource == "NPU" ? 'modelarts/notebook' : 'cloudbrain'
            $.get(`/api/v1/repos/${repoPath}/${jobID}?version_name=${versionname}`, (data) => {
                const jobID = data.JobID
                const status = data.JobStatus
                const duration = data.JobDuration
                $('#duration-'+jobID).text(duration)
                if (status != status_text) {
                    $('#' + jobID+'-icon').removeClass().addClass(status)
                    $('#' + jobID+ '-text').text(status)
                    finalState.includes(status) && $('#' + jobID + '-stop').removeClass('blue').addClass('disabled')
                }
                if(status==="RUNNING"){
                    $('#ai-debug-'+jobID).removeClass('disabled').addClass('blue').text('调试').css("margin","0 1rem")
                    $('#model-image-'+jobID).removeClass('disabled').addClass('blue')
                }
                if(status!=="RUNNING"){
                    // $('#model-debug-'+jobID).removeClass('blue')
                    // $('#model-debug-'+jobID).addClass('disabled')
                    $('#model-image-'+jobID).removeClass('blue').addClass('disabled')
                }
                if(["CREATING","STOPPING","WAITING","STARTING"].includes(status)){
                    $('#ai-debug-'+jobID).removeClass('blue').addClass('disabled')
                }
                if(['STOPPED','FAILED','START_FAILED','CREATE_FAILED','SUCCEEDED'].includes(status)){
                    $('#ai-debug-'+jobID).removeClass('disabled').addClass('blue').text('再次调试').css("margin","0") 
                }
                if(["RUNNING","WAITING"].includes(status)){
                    $('#ai-stop-'+jobID).removeClass('disabled').addClass('blue')
                }
                if(["CREATING","STOPPING","STARTING","STOPPED","FAILED","START_FAILED","SUCCEEDED"].includes(status)){
                    $('#ai-stop-'+jobID).removeClass('blue').addClass('disabled')
                }
                
                if(["STOPPED","FAILED","START_FAILED","KILLED","COMPLETED","SUCCEEDED"].includes(status)){
                    $('#ai-delete-'+jobID).removeClass('disabled').addClass('blue')
                }else{
                    $('#ai-delete-'+jobID).removeClass('blue').addClass('disabled')
                }
            }).fail(function(err) {
                console.log(err);
            });
        });
    };
    function assertDelete(obj,versionName,repoPath) {
        if (obj.style.color == "rgb(204, 204, 204)") {
            return
        } else {
            const delId = obj.parentNode.id
            let flag = 1;
            $('.ui.basic.modal')
                .modal({
                    onDeny: function() {
                        flag = false
                    },
                    onApprove: function() {
                        if(!versionName){
                            document.getElementById(delId).submit()
                        }
                        else{
                            deleteVersion(versionName,repoPath)
                        }
                        flag = true
                    },
                    onHidden: function() {
                        if (flag == false) {
                            $('.alert').html('您已取消操作').removeClass('alert-success').addClass('alert-danger').show().delay(1500).fadeOut();
                        }
                    }
                })
                .modal('show')
        }
    }
    function deleteVersion(versionName,repoPath){
        const url = `/api/v1/repos/${repoPath}`
        $.post(url,{version_name:versionName},(data)=>{
            if(data.StatusOK===0){
                location.reload()
            }
        }).fail(function(err) {
            console.log(err);	            
        });
    }
    $('.ui.basic.ai_delete').click(function() {
        const repoPath = this.dataset.repopath
        const versionName = this.dataset.version
        if(repoPath && versionName){
            assertDelete(this,versionName,repoPath)
        }
        else{
            assertDelete(this)
        }
    })
    function stopDebug(JobID,stopUrl){
        $.ajax({
            type:"POST",
            url:stopUrl,
            data:$('#stopForm-'+JobID).serialize(),
            success:function(res){
                if(res.result_code==="0"){
                    $('#' + JobID+'-icon').removeClass().addClass(res.status)
                    $('#' + JobID+ '-text').text(res.status)
                    if(res.status==="STOPPED"){
                        $('#ai-debug-'+JobID).removeClass('disabled').addClass('blue').text("再次调试").css("margin","0")
                        $('#ai-image-'+JobID).removeClass('blue').addClass('disabled')
                        $('#ai-model-debug-'+JobID).removeClass('blue').addClass('disabled')
                        $('#ai-delete-'+JobID).removeClass('disabled').addClass('blue')
                        $('#ai-stop-'+JobID).removeClass('blue').addClass('disabled')
                    }
                    else{
                        $('#ai-debug-'+JobID).removeClass('blue').addClass('disabled')
                        $('#ai-stop-'+JobID).removeClass('blue').addClass('disabled')
                    }
                    
                }else{
                    $('.alert').html(res.error_msg).removeClass('alert-success').addClass('alert-danger').show().delay(2000).fadeOut();
                }
            },
            error :function(res){
                console.log(res)
        
            }
        })
    }
    $('.ui.basic.ai_stop').click(function() {
        const jobID = this.dataset.jobid
        const repoPath = this.dataset.repopath
        stopDebug(jobID,repoPath)
    })

    function stopVersion(version_name,jobID,repoPath){
        const url = `/api/v1/repos/${repoPath}/${jobID}/stop_version`
        $.post(url,{version_name:version_name},(data)=>{
            if(data.StatusOK===0){
                $('#ai-stop-'+jobID).removeClass('blue')
                $('#ai-stop-'+jobID).addClass('disabled')
                refreshStatus(version_name,jobID,repoPath)
            }
        }).fail(function(err) {
            console.log(err);	            
        });
    }
    function refreshStatus(version_name,jobID,repoPath){
    
        const url = `/api/v1/repos/${repoPath}/${jobID}/?version_name${version_name}`
        $.get(url,(data)=>{
            $(`#${jobID}-icon`).attr("class",data.JobStatus)
            // detail status and duration
            $(`#${jobID}-text`).text(data.JobStatus)
        }).fail(function(err) {
            console.log(err);
        });
    }
    $('.ui.basic.ai_stop_version').click(function() {
        const jobID = this.dataset.jobid
        const repoPath = this.dataset.repopath
        const versionName = this.dataset.version
        stopVersion(versionName,jobID,repoPath)
    })
    function getModelInfo(repoPath,modelName,versionName,jobName){
        console.log("getModelInfo")
        $.get(`${repoPath}/modelmanage/show_model_info_api?name=${modelName}`,(data)=>{
            if(data.length===0){
                $(`#${jobName}`).popup('toggle')
            }else{
                let versionData = data.filter((item)=>{
                    return item.Version === versionName
                })
                if(versionData.length==0){
                    $(`#${jobName}`).popup('toggle')
                }
                else{
                    location.href = `${repoPath}/modelmanage/show_model_info?name=${modelName}`
                }
            }
        })
    }
    $('.goto_modelmanage').click(function() {
        const repoPath = this.dataset.repopath
        const modelName = this.dataset.modelname
        const versionName = this.dataset.version
        const jobName = this.dataset.jobname
        getModelInfo(repoPath,modelName,versionName,jobName)
    })
    function debugAgain(JobID,debugUrl,redirect_to){
        if($('#' + JobID+ '-text').text()==="RUNNING"){
            window.open(debugUrl+'debug')
        }else{
            $.ajax({
                type:"POST",
                url:debugUrl+'restart?redirect_to='+redirect_to,
                data:$('#debugAgainForm-'+JobID).serialize(),
                success:function(res){
                    if(res['WechatRedirectUrl']){
                        window.location.href=res['WechatRedirectUrl']
                    }
                    else if(res.result_code==="0"){
                        if(res.job_id!==JobID){
                            location.reload()
                        }else{
                            $('#' + JobID+'-icon').removeClass().addClass(res.status)
                            $('#' + JobID+ '-text').text(res.status)
                            $('#ai-debug-'+JobID).removeClass('blue').addClass('disabled')
                            $('#ai-delete-'+JobID).removeClass('blue').addClass('disabled')
                            $('#ai-debug-'+JobID).text("调试").css("margin","0 1rem")
                        }
                    }else{
                        $('.alert').html(res.error_msg).removeClass('alert-success').addClass('alert-danger').show().delay(2000).fadeOut();
                    }
                },
                error :function(res){
                    console.log(res)
                }
            })
        }
    }
    $('.ui.basic.ai_debug').click(function() {
        const jobID = this.dataset.jobid
        const repoPath = this.dataset.repopath
        const redirect_to = this.dataset.linkpath
        debugAgain(jobID,repoPath,redirect_to)
    })
}

    